'use strict';

/**
 * Creates a {@link TranslateFunction} that utilises the provided
 * {@link IntlController}.
 *
 * @param controller Controller to use for translations.
 * @returns Function to use translations from the controller.
 */
function createTranslateFunction(controller) {
  return function translateAndNormalize(descriptor, values, opts) {
    let result = '';
    const normalizedDescriptor = typeof descriptor === 'string' ? {
      id: descriptor,
      defaultMessage: controller.defaultMessages[descriptor]
    } : descriptor;
    result = controller.intl.formatMessage(normalizedDescriptor, values, opts);
    if (typeof result === 'string') {
      return result;
    }
    if (Array.isArray(result)) {
      let normalizedResult = '';
      for (const item of result) {
        normalizedResult += String(item);
      }
      return normalizedResult;
    }
    return String(result);
  };
}

exports.createTranslateFunction = createTranslateFunction;
